function [ICb1Inf,ICb1Sup,yc0,ICy0Inf,ICy0Sup] = regtest(x,y,b0,b1,alpha,x0) 

% REGTEST :          Intervalle de confiance (Test de Student) pour
%    la pente d'une rgression linaire et la prvision, selon cette
%    rgression en un point x0 fix.
%
% [ICb1Inf,ICb1Sup,yc0,ICy0Inf,ICy0Sup] = regtest(x,y,b0,b1,alpha,x0);
%
% Entres :
% ---------
% x, y   : Vecteurs des coordonnes des points rgresss par la droite 
%          de coefficients b0 et b1 passs ci-aprs
% b0, b1 : Coefficients de la droite de rgression (y=b0+b1*x)
% alpha  : Pourcentage du risque d'erreur accept pour l'intervalle 
%          de confiance
% x0     : Valeur du point d'abscisse sur lequel on se positionne pour
%          faire une prvision selon la rgression.
%
% Sorties :
% ---------
% [ICb1Inf ICb1Sup] : Bornes inf et sup de l'intervalle de confiance sur
%                     la pente 
% Si 6 arguments sont passs (c'est  dire, si x0 est pass) :
% yc0               : Valeur de la rgression au point x0
% [ICy0Inf ICy0Sup] : Bornes inf et sup de l'intervalle de confiance 
%                     pour la prvision de y0 au point x0

%_________________________________________________________
% Auteur : C.Sorror (avril 2012)
% --------------------------------------------------------
n=length(x);
if (length(y) ~= n)
   error('b1test: vecteurs de dimensions differentes');
   return
end
%
% yc = y calcul par la rgression
yc = b0+b1*x; 
%
% s : Erreur Type de l'Estimation 
s = sqrt(sum((y-yc).^2)/(n-2));
%
meanx = mean(x);
%
% Ecart Type b1
ETb1 = s / sqrt(sum((x-meanx).^2)); % (c'est sigb1 de linreg)
%
% Table de Student 
tstud = tinv((1 - alpha / 2),n - 2); % trouv dans ttest
% 
% Intervalle de confiance sur la pente :
ICb1Inf = b1-tstud*ETb1; 
ICb1Sup = b1+tstud*ETb1; 
%
%disp(['Intervalle de confiance : [',num2str(ICb1Inf),'  ',num2str(ICb1Sup),']']);

%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++
% Intervalle de confiance sur la prvision
if (nargin==6)
   % Variance de l'erreur de prvision
   pevar = s^2*(1 + 1/n + (x0-meanx)^2/sum((x-meanx).^2));
   sqpevar = sqrt(pevar);
   %
   % Valeur calcule sur la rgression pour x0 :
   yc0 = b0+b1*x0;
   %
   % Intervalle de confiance sur la prvision :
   ICy0Inf = yc0-tstud*sqpevar; 
   ICy0Sup = yc0+tstud*sqpevar;
end
%+++++++++++++++++++++++++++++++++++++++++++++++++++++++++

